Given a fitted model by the exact NPMLE procedure prediction is made at a new design point with lower and upper bounds for the prediction due to ambiguity of the assignment of mass within the cell enumerated polygons.
bounds.KW2(object, ...)a list consisting of the following components:
Point prediction
lower bound prediction
upper bound prediction
indices of crossed polygons
is the fitted NPMLE object
is expected to contain an argument newdata
Jiaying Gu
predict.KW2 for a simpler prediction function without bounds